const system = require("../../../system");
var settings = require("../../../../config/settings");
const AppServiceBase = require("../../app.base");

class FblicenseService extends AppServiceBase {
  constructor () {
    super();
    this.centerOrderUrl = settings.centerOrderUrl()
    this.restClient = system.getObject("util.restClient")
  };

  //获取列表、检索
  async getList (pobj) {
    try {
      let url = `${this.centerOrderUrl}action/diagnosisneedbus/springBoard`
      pobj.actionType = 'getList'
      let result = await this.restClient.execPost(pobj, url)
      return JSON.parse(result.stdout)
    } catch (error) {
      return system.getResultFail(-1, error.message || 'failed')
    }
  }

  // 获取详情
  async getDetail (pobj) {
    try {
      let url = `${this.centerOrderUrl}action/diagnosisneedbus/springBoard`
      pobj.actionType = 'getDetail'
      let result = await this.restClient.execPost(pobj, url)
      let data = JSON.parse(result.stdout)
      if (data.status != 0)
        return system.getResultFail(-1, error.message || 'failed')
      return data;
    } catch (error) {
      return system.getResultFail(-1, error.message || 'failed')
    }
  }

  // 认证
  async doEAV (pobj) {
    try {
      let url = `${this.centerOrderUrl}action/diagnosisneedbus/springBoard`
      pobj.actionType = 'doEAV'
      let result = await this.restClient.execPost(pobj, url)
      return JSON.parse(result.stdout)
    } catch (error) {
      return system.getResultFail(-1, error.message || 'failed')
    }
  }

  // 获取需求列表
  async getNeedList (pobj) {
    try {
      let url = `${this.centerOrderUrl}action/diagnosisneedbus/springBoard`
      pobj.actionType = 'getNeedList'
      let result = await this.restClient.execPost(pobj, url)
      return JSON.parse(result.stdout)
    } catch (error) {
      return system.getResultFail(-1, error.message || 'failed')
    }
  }
  // 获取需求详情
  async getNeedDetail (pobj) {
    try {
      let url = `${this.centerOrderUrl}action/diagnosisneedbus/springBoard`
      pobj.actionType = 'getNeedDetail'
      let result = await this.restClient.execPost(pobj, url)
      return JSON.parse(result.stdout)
    } catch (error) {
      return system.getResultFail(-1, error.message || 'failed')
    }
  }

  async licenseCompare (pobj) {
    let res = {
      "Message": "查询成功",
      "OrderNumber": null,
      "Result": {
        "Data": {
          "中央厨房": "否",
          "主体业态": "单位食堂",
          "住所": "新疆维吾尔自治区伊犁州伊宁县伊东工业园管委会",
          "发证日期": "2018年07月19日",
          "发证机关": "伊宁县市场监督管理局",
          "散装熟食销售": "否",
          "日常监督管理人员": "杜爱洪加拉斯",
          "日常监督管理机构": "伊宁县市场监督管理局",
          "有效期至": "2023年07月18日",
          "法定代表人（负责人）": "霍庆华",
          "监督举报电话": "",
          "签发人": "马江平",
          "经营场所": "新疆维吾尔自治区伊犁州伊宁县伊东工业园管委会",
          "经营者名称": "新疆庆华能源集团有限公司",
          "经营项目": "热食类食品制售,",
          "网络经营": "否",
          "许可证状态": "有效",
          "许可证编号": "JY36540210003935",
          "集体用餐配送单位": "否"
        },
        "Id": "85eb513de02c7ff8199bda197992888c",
        "Schema": null
      },
      "Status": "200"
    }
    if (res.Status == 200) {
      let result = res.Result.Data
      let keys = Object.keys(result)
      for (let i of keys) {
        if (!result[i]) {
          delete result[i]
        }
      }
      return {
        status: 0,
        msg: "success",
        data: result
      }
    } else {
      return {
        status: -1,
        msg: res.Message
      }
    }
  }
}

module.exports = FblicenseService;
